#!/usr/bin/perl

use strict;
use Test::More tests => 119;
use FDN::Common::Constantes;

# 1
BEGIN { use_ok('FDN::Common::Validate'); }

# 2
ok ( Is_Domain('fdn.fr'), 'domaine' );

# 3
ok ( ! Is_Domain('fr.fdn'), 'domaine' );

# 4
ok ( Is_RFC822Domain('fdn.fr.invalid'), 'domaine-mail');

# 5
ok ( Is_RFC822Email('bayartb@edgard.fdn.fr.invalid'), 'mail');

# 6
ok ( ! Is_RFC822Email('bayartb@edgard.fdn.fr.invalid',1), 'mail');

# 7
ok ( Is_RFC822Email('bayartb@edgard.fdn.fr',1), 'mail');

# 8
ok ( ! Is_Email('bayartb@edgard.fdn.fr.invalid'), 'mail');

# 9
ok ( ! Is_Email('bayartb@edgard.fdn.fr.invalid',1), 'mail');

# 10
ok ( Is_Email('bayartb@edgard.fdn.fr',1), 'mail');

# 11
ok ( Is_IPv4('1.2.3.4'), 'ip');

# 12
ok ( ! Is_IPv4('256.0.0.0'), 'ip');

# 13
ok ( ! Is_IPv4('a.b.c.d'), 'ip');

# 14
ok ( ! Is_Public_IPv4('10.0.0.1'), 'ip');

# 15
ok ( ! Is_Public_IPv4('127.0.0.1'), 'ip');

# 16
ok ( Is_Public_IPv4('80.67.169.12'), 'ip');

# 17
ok ( ! Is_Netmask('255.255.255.253'), 'ip');

# 18
ok ( ! Is_Netmask('35'), 'ip');

# 19
ok ( Is_Netmask('192.0.0.0'), 'ip');

# 20
ok ( ! Is_RR_Ttl('12min'), 'dns' );

# 21
ok ( Is_RR_Ttl('2d'), 'dns' );

# 22
ok ( Is_RR_Name('toto'), 'dns' );

# 23
ok ( ! Is_RR_Name('burps!'), 'dns' );

# 24
ok ( Is_RR_Name('www.mc.corp.fr','corp.com'), 'dns');

# 25
ok ( Is_RR_Name('www.mc.cort.fr','corp.fr'), 'dns');

# 26
ok ( Is_RR_Name('www.mc.corp.fr.', 'corp.fr'), 'dns');

# 27
ok ( ! Is_RR_Name('www.mc.corp.fr.', 'corp.be'), 'dns');

# 28
ok ( Is_RR_Type('A'), 'dns');

# 29
ok ( Is_RR_Type('MX 12'), 'dns');

# 30
ok ( ! Is_RR_Type('NS 12'), 'dns');

# 31
ok ( ! Is_RR_Type('machin'), 'dns');

# 32
ok ( ! Is_RR_Data('www.fdn.fr.', 'A'), 'dns');

# 33
ok ( Is_RR_Data('www.fdn.fr.', 'PTR'), 'dns');

# 34
ok ( Is_RR_Data('1.2.3.4', 'A'), 'dns');

# 35
ok ( ! Is_RR_Data('256.0.0.0', 'A'), 'dns');

# 36
ok ( ! Is_RR_Data('1.2.3.4/32', 'MX 12'), 'dns');

# 37
ok ( Is_RR_Data('1.2.3.4', 'A'), 'dns');

# 38
ok ( Is_NAF_Code('000A'), 'infos');

# 39
ok ( ! Is_NAF_Code('toto'), 'infos');

# 40
ok ( Is_SIREN_Code('000000000'), 'infos');

# 41
ok ( ! Is_SIREN_Code('toto'), 'infos');

# 42
ok ( ! Is_SIRET_Code('000000000'), 'infos');

# 43
ok ( Is_SIRET_Code('12345678912345'), 'infos');

# 44
ok ( ! Is_SIRET_Code('toto'), 'infos');

# 45
ok ( ! Is_INSEE_Code('toto'), 'infos');

# 46
ok ( ! Is_INSEE_Code('123456789'), 'infos');

# 47
ok ( Is_INSEE_Code('12345'), 'infos');

# 48
ok ( Is_YYYYMMDD_Date('20050531'), 'date');

# 49
ok ( ! Is_YYYYMMDD_Date('20051335'), 'date');

# 50
ok ( ! Is_HHMMSS_Time('535353'), 'date');

# 51
ok ( Is_HHMMSS_Time('235959'), 'date');

# 52
ok ( ! Is_Timestamp14('123456'), 'date');

# 53
ok ( ! Is_Timestamp14('12345678901234'), 'date');

# 54
ok ( Is_Timestamp14('20050531235959'), 'date');

# 55
ok ( ! Is_Timestamp14('20050531250202'), 'date');

# 56
ok ( ! Is_Timestamp8('coucou'), 'date');

# 57
ok ( ! Is_Timestamp8('12345678'), 'date');

# 58
ok ( Is_Timestamp8('19731024'), 'date');

# 59
is ( Is_Boolean('y'), TRUE, 'tyoe');

# 60
is ( Is_Boolean('n'), FALSE, 'type');

# 61
is ( Is_Boolean('2'), undef, 'type');

# 62
is ( Is_Number('42'), 42, 'type');

# 63
is ( Is_Number('+12'), 12, 'type');

# 64
is ( Is_Number('rien'), undef, 'type');

# 65
is ( Is_Number('+2',0), 2, 'type');

# 66
is ( Is_Number('2',undef,8), 2, 'type');

# 67
is ( Is_Number(2,3), undef, 'type');

# 68
is ( Is_Number(2,undef,1), undef, 'type');

# 69
is ( Is_Number(2,4,5), undef, 'type');

# 70
is ( Is_Number(3,34,21), undef, 'type');

# 71
is ( Is_Integer('1'), 1, 'type');

# 72
is ( Is_Integer('-1'), -1, 'type');

# 73
is ( Is_Integer('+1'), 1, 'type');

# 74
is ( Is_Integer('toto'), undef, 'type');

# 75
is ( Is_Integer('1',2), undef, 'type');

# 76
is ( Is_Integer('3',undef,2), undef, 'type');

# 77
is ( Is_Integer('2',0,5), 2, 'type');

# 78
is ( Is_Integer(-3,-3,1), -3, 'type');

# 79
is ( Is_Integer(-3,-2,-1), undef, 'type');

# 80
is ( Is_Vlan(0), undef, 'net');

# 81
is ( Is_Vlan(1), 1, 'net');

# 82
is ( Is_Vlan(4096), 4096, 'net');

# 83
is ( Is_Vlan(4097), undef, 'net');

# 84
is ( Is_Vlan('4096-1'), undef, 'net');

# 85
is ( Is_Vrid(0), 0, 'net');

# 86
is ( Is_Vrid(255), 255, 'net');

# 87
is ( Is_Vrid(256), undef, 'net');

# 88
is ( Is_Vrid('toto'), undef, 'net');

# 89
is ( Is_Ipv4('1.2.3.4'), '1.2.3.4', 'net');

# 90
is ( Is_Ipv4('001.002.003.004'), '1.2.3.4', 'net');

# 91
is ( Is_Ipv4('plouf'), undef, 'net');

# 92
is ( Is_Ipv4('256.0.0.0'), undef, 'net');

# 93
is ( Is_Port(25), 25, 'net');

# 94
is ( Is_Port(8080), 8080, 'net');

# 95
is ( Is_Port('rien'), undef, 'net');

# 96
is ( Is_Port(-1), undef, 'net');

# 97
is ( Is_Port('081'), 81, 'net');

# 98
is ( Is_Port_Range('rien-dutout'), undef, 'net');

# 99
is ( Is_Port_Range('1-2'), '1-2', 'net');

# 100
is ( Is_Port_Range('2-1'), undef, 'net');

# 101
is ( Is_Cidr('1.2.3.4/24'), '1.2.3.4/24', 'net');

# 102
is ( Is_Cidr('1.2.3.4/255.255.255.0'), '1.2.3.4/24', 'net');

# 103
is ( Is_Cidr('1.2.3.4'), '1.2.3.4/32', 'net');

# 104
is ( Is_Cidr('1.2.3.4/33'), undef, 'net');

# 105
is ( Is_Cidr('1.2.3.4/24', CIDR_LONG), '1.2.3.4/255.255.255.0', 'net');

# 106
is ( Is_Cidr('1.2.3.4/255.255.255.0', CIDR_LONG), '1.2.3.4/255.255.255.0', 'net');

# 107
is ( Is_Cidr('1.2.3.4', CIDR_LONG), '1.2.3.4/255.255.255.255', 'net');

# 108
is ( Is_Cidr('rien'), undef, 'net');

# 109
is ( Is_Host('1.2.3.4'), '1.2.3.4', 'net');

# 110
is ( Is_Host('rien'), 'rien', 'net');

# 111
is ( Is_Host('rien du tout'), undef, 'net');

# 112
is ( Is_Mib_Oid('1.1.1.1.0'), '1.1.1.1.0', 'snmp');

# 113
is ( Is_Mib_Oid('.1.1'), '1.1', 'snmp');

# 114
is ( Is_Mib_Oid('rien'), undef, 'snmp');

# 115
is ( Is_Member('un', [0,'un',2,3,4]), 1, 'utils');

# 116
is ( Is_Member(1, [0,'un',2,3,4]), -1, 'utils');

# 117
is ( Is_Member(undef, [undef,1]), undef, 'utils');

# 118
is ( Is_Member('un', {1=>2}), undef, 'utils');

# 119
is ( Is_Member(1,{1=>2}), undef, 'utils');


